@@ -26,9 +26,11 @@ command_dict = {}
 
 arg_number = 0
 
+bot_token = ""
+
 class simple_discord_bot(discord.Client):
     def __init__(self, token):
-        self.bot_token = token
+        self.token = token
     def add_command(self, command_to_add, response, react_to=None, reaction=None, delete=False, connect_to_voicechannel=False, source_to_play=None, DM=False):
 
         command_dict[str(command_to_add)] = {
@@ -219,8 +221,11 @@ async def on_message(message):
                 except Exception as DM_error:
                     print(str(DM_error))
 
+    def set_token(self, token):
+        bot_token = token
+
 try:
     print("Attempting to login to Discord...")
-    client.run(simple_discord_bot.bot_token)
+    client.run(bot_token)
 except Exception as login_error:
     print(login_error)
